aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/northbridge/intel/x4x/rcven.c12
1 files changed, 7 insertions, 5 deletions
diff --git a/src/northbridge/intel/x4x/rcven.c b/src/northbridge/intel/x4x/rcven.c
index 8a86ce9cb5..1f49beb61c 100644
--- a/src/northbridge/intel/x4x/rcven.c
+++ b/src/northbridge/intel/x4x/rcven.c
@@ -28,11 +28,13 @@ static u8 sampledqs(u32 addr, u8 lane, u8 channel)
{
u32 sample_offset = 0x400 * channel + 0x561 + lane * 4;
- /* Reset the DQS probe */
- MCHBAR8(RESET_CNTL(channel)) &= ~0x2;
- udelay(2);
- MCHBAR8(RESET_CNTL(channel)) |= 0x2;
- udelay(2);
+ /* Reset the DQS probe, on both channels? */
+ for (u8 i = 0; i < TOTAL_CHANNELS; i++) {
+ MCHBAR8(RESET_CNTL(i)) &= ~0x2;
+ udelay(1);
+ MCHBAR8(RESET_CNTL(i)) |= 0x2;
+ udelay(1);
+ }
mfence();
/* Read strobe */
read32((u32 *)addr);